@@ -68,7 +68,6 @@ class DiscoverObject : public QObject
         void openLocalPackage(const QUrl &localfile);
 
     private Q_SLOTS:
-        void appHelpActivated();
         void reportBug();
         void switchApplicationLanguage();
         void aboutApplication();
@@ -82,8 +81,10 @@ class DiscoverObject : public QObject
         void compactModeChanged(CompactMode compactMode);
         void preventedClose();
         void unableToFind(const QString &resid);
+        void openErrorPage(const QString &errorMessage);
 
     private:
+        void setRootObjectProperty(const char *name, const QVariant &value);
         void integrateObject(QObject* object);
         QQmlApplicationEngine* engine() const { return m_engine; }
 
