@@ -22,6 +22,8 @@
 
 #include <resources/AbstractResource.h>
 #include "TransactionModel.h"
+#include <KFormat>
+#include <KLocalizedString>
 #include <QDebug>
 
 Transaction::Transaction(QObject *parent, AbstractResource *resource,
@@ -40,8 +42,8 @@ Transaction::~Transaction()
 {
     if(status()<DoneStatus || TransactionModel::global()->contains(this)) {
         qWarning() << "destroying Transaction before it's over" << this;
+        TransactionModel::global()->removeTransaction(this);
     }
-    TransactionModel::global()->removeTransaction(this);
 }
 
 AbstractResource *Transaction::resource() const
@@ -132,3 +134,16 @@ void Transaction::setVisible(bool visible)
         Q_EMIT visibleChanged(visible);
     }
 }
+
+void Transaction::setDownloadSpeed(quint64 downloadSpeed)
+{
+    if (downloadSpeed != m_downloadSpeed) {
+        m_downloadSpeed = downloadSpeed;
+        Q_EMIT downloadSpeedChanged(downloadSpeed);
+    }
+}
+
+QString Transaction::downloadSpeedString() const
+{
+    return i18nc("@label Download rate", "%1/s", KFormat().formatByteSize(downloadSpeed()));
+}
