@@ -82,20 +82,20 @@ void KNSReviews::fetchReviews(AbstractResource* app, int page)
     job->setProperty("app", qVariantFromValue<AbstractResource*>(app));
     connect(job, &Attica::BaseJob::finished, this, &KNSReviews::commentsReceived);
     job->start();
+    m_fetching++;
 }
 
 void KNSReviews::commentsReceived(Attica::BaseJob* j)
 {
+    m_fetching--;
     Attica::ListJob<Attica::Comment>* job = static_cast<Attica::ListJob<Attica::Comment>*>(j);
     Attica::Comment::List comments = job->itemList();
 
     QVector<ReviewPtr> reviews;
-    reviews.reserve(comments.count());
     AbstractResource* app = job->property("app").value<AbstractResource*>();
     foreach(const Attica::Comment& comment, comments) {
         //TODO: language lookup?
-        const QString subject = comment.subject().isEmpty() ? QStringLiteral(".") : comment.subject();
-        ReviewPtr r(new Review(app->name(), app->packageName(), QStringLiteral("en"), subject, comment.text(), comment.user(),
+        ReviewPtr r(new Review(app->name(), app->packageName(), QStringLiteral("en"), comment.subject(), comment.text(), comment.user(),
             comment.date(), true, comment.id().toInt(), comment.score()/10, 0, 0, QString()
         ));
         reviews += r;
@@ -106,7 +106,7 @@ void KNSReviews::commentsReceived(Attica::BaseJob* j)
 
 bool KNSReviews::isFetching() const
 {
-    return m_backend->isFetching();
+    return m_fetching > 0;
 }
 
 void KNSReviews::flagReview(Review*  /*r*/, const QString&  /*reason*/, const QString&  /*text*/)
