@@ -24,6 +24,7 @@
 #include <AppStreamQt/image.h>
 #include <AppStreamQt/release.h>
 #include <appstream/AppStreamUtils.h>
+#include <PackageKit/Daemon>
 #include <KLocalizedString>
 #include <KToolInvocation>
 #include <QIcon>
@@ -31,6 +32,7 @@
 #include <QStandardPaths>
 #include <QDebug>
 #include "config-paths.h"
+#include "utils.h"
 
 AppPackageKitResource::AppPackageKitResource(const AppStream::Component& data, const QString &packageName, PackageKitBackend* parent)
     : PackageKitResource(packageName, QString(), parent)
@@ -44,9 +46,14 @@ QString AppPackageKitResource::name() const
     QString ret;
     if (!m_appdata.extends().isEmpty()) {
         auto components = backend()->componentsById(m_appdata.extends().constFirst());
-        Q_ASSERT(!components.isEmpty());
-        ret = components.constFirst().name() + QStringLiteral(" - ") + m_appdata.name();
-    } else
+
+        if (components.isEmpty())
+            qWarning() << "couldn't find" << m_appdata.extends() << "which is supposedly extended by" << m_appdata.id();
+        else
+            ret = components.constFirst().name() + QStringLiteral(" - ") + m_appdata.name();
+    }
+
+    if (ret.isEmpty())
         ret = m_appdata.name();
     return ret;
 }
@@ -199,13 +206,33 @@ void AppPackageKitResource::fetchChangelog()
 
 void AppPackageKitResource::invokeApplication() const
 {
-    const QStringList exes = m_appdata.provided(AppStream::Provided::KindBinary).items();
-    if (exes.isEmpty()) {
-        const auto servicePath = QStandardPaths::locate(QStandardPaths::ApplicationsLocation, m_appdata.id());
-        QProcess::startDetached(QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/discover/runservice"), {servicePath});
-    } else {
-        QProcess::startDetached(exes.constFirst());
-    }
+    auto trans = PackageKit::Daemon::getFiles({installedPackageId()});
+    connect(trans, &PackageKit::Transaction::files, this, [this](const QString &/*packageID*/, const QStringList &filenames) {
+        const auto allServices = QStandardPaths::locateAll(QStandardPaths::ApplicationsLocation, m_appdata.id());
+        if (!allServices.isEmpty()) {
+            const auto packageServices = kFilter<QStringList>(allServices, [filenames](const QString &file) { return filenames.contains(file); });
+            QProcess::startDetached(QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/discover/runservice"), {packageServices});
+        } else {
+            const QStringList exes = m_appdata.provided(AppStream::Provided::KindBinary).items();
+            const auto packageExecutables = kFilter<QStringList>(allServices, [filenames](const QString &exe) { return filenames.contains(QLatin1Char('/') + exe); });
+            if (!packageExecutables.isEmpty()) {
+                QProcess::startDetached(exes.constFirst());
+            } else {
+                const auto locations = QStandardPaths::standardLocations(QStandardPaths::ApplicationsLocation);
+                const auto desktopFiles = kFilter<QStringList>(filenames, [locations](const QString &exe) {
+                    for (const auto &location: locations) {
+                        if (exe.startsWith(location))
+                            return exe.contains(QLatin1String(".desktop"));
+                    }
+                    return false;
+                });
+                if (!desktopFiles.isEmpty()) {
+                    QProcess::startDetached(QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/discover/runservice"), { desktopFiles });
+                }
+            }
+            qWarning() << "Could not find any executables" << exes << filenames;
+        }
+    });
 }
 
 QDate AppPackageKitResource::releaseDate() const
