@@ -52,6 +52,7 @@ class DISCOVERCOMMON_EXPORT ResourcesProxyModel : public QAbstractListModel, pub
     Q_PROPERTY(bool allBackends READ allBackends WRITE setAllBackends)
     Q_PROPERTY(QVariantList subcategories READ subcategories NOTIFY subcategoriesChanged)
     Q_PROPERTY(bool isBusy READ isBusy NOTIFY busyChanged)
+    Q_PROPERTY(int count READ rowCount NOTIFY countChanged)
 public:
     explicit ResourcesProxyModel(QObject* parent = nullptr);
     enum Roles {
@@ -76,7 +77,8 @@ public:
         MimeTypes,
         SizeRole,
         LongDescriptionRole,
-        AvailableVersionRole
+        SourceIconRole,
+        ReleaseDateRole
     };
     Q_ENUM(Roles)
 
@@ -137,6 +139,7 @@ private:
     void addResources(const QVector<AbstractResource*> &res);
     void fetchSubcategories();
     void removeDuplicates(QVector<AbstractResource *>& newResources);
+    bool isSorted(const QVector<AbstractResource*> & resources);
 
     Roles m_sortRole;
     Qt::SortOrder m_sortOrder;
@@ -160,6 +163,7 @@ Q_SIGNALS:
     void searchChanged(const QString &search);
     void subcategoriesChanged(const QVariantList &subcategories);
     void resourcesUrlChanged(const QUrl &url);
+    void countChanged();
 };
 
 #endif
